@@ -1,7 +1,7 @@
 mod core;
 mod utils;
 
-use crate::core::{compile, ErrKind, VM};
+use crate::core::{compile, Code, ErrKind, VM};
 use crate::utils::load_code_from_file;
 
 pub fn compile_and_run(path: &str) -> Result<Vec<i32>, ErrKind> {
@@ -11,6 +11,15 @@ pub fn compile_and_run(path: &str) -> Result<Vec<i32>, ErrKind> {
     vm.execute()
 }
 
+pub fn compile_to_code(path: &str) -> Result<Vec<Code>, ErrKind> {
+    let code = load_code_from_file(path);
+    let prog = compile(&code)?;
+    for c in prog.codes.iter() {
+        println!("{:?}", c.clone());
+    }
+    Ok(prog.codes)
+}
+
 #[cfg(test)]
 mod tests {
     use super::compile_and_run;
